@@ -1,16 +1,16 @@
 use crate::renderer::HtmlMdzk;
 use crate::{cmd::watch, load_zk};
+use anyhow::{anyhow, Result};
 use futures_util::sink::SinkExt;
 use futures_util::StreamExt;
 use mdbook::{
-    errors::*,
     renderer::{HtmlHandlebars, MarkdownRenderer},
     utils,
     utils::fs::get_404_output_file,
     MDBook,
 };
 use std::net::{SocketAddr, ToSocketAddrs};
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 use tokio::sync::broadcast;
 use toml;
 use warp::ws::Message;
@@ -19,24 +19,24 @@ use warp::Filter;
 /// The HTTP endpoint for the websocket used to trigger reloads when a file changes.
 const LIVE_RELOAD_ENDPOINT: &str = "__livereload";
 
-pub fn serve(dir: Option<PathBuf>, port: i32, bind: String, renderer: String) -> Result<(), Error> {
+pub fn serve(dir: Option<PathBuf>, port: i32, bind: String, renderer: String) -> Result<()> {
     let mut zk = load_zk(dir)?;
 
-    let address = format!("{}:{}", bind, port.to_string());
+    let address = format!("{}:{}", bind, port);
 
     let livereload_url = format!("ws://{}/{}", address, LIVE_RELOAD_ENDPOINT);
     update_config(&mut zk, &livereload_url)?;
 
     match renderer.as_str() {
         "markdown" => zk.execute_build_process(&MarkdownRenderer)?,
-        "mdzk" => zk.execute_build_process(&HtmlMdzk)?,
-        _ => zk.execute_build_process(&HtmlHandlebars)?,
+        "mdbook" => zk.execute_build_process(&HtmlHandlebars)?,
+        _ => zk.execute_build_process(&HtmlMdzk)?,
     }
 
     let sockaddr: SocketAddr = address
         .to_socket_addrs()?
         .next()
-        .ok_or_else(|| Error::msg("no address found for ".to_string() + &address))?;
+        .ok_or_else(|| anyhow!("no address found for ".to_string() + &address))?;
     let build_dir = zk.build_dir_for("html");
     let input_404 = zk
         .config
@@ -55,18 +55,17 @@ pub fn serve(dir: Option<PathBuf>, port: i32, bind: String, renderer: String) ->
     });
 
     let serving_url = format!("http://{}", address);
-    info!("Serving on: {}", serving_url);
+    success!("Serving your mdzk on: {}.", serving_url);
 
     /* if open_browser {
         open(serving_url);
     } */
 
-    watch::trigger_on_change(&zk, move |paths, book_dir| {
+    watch::trigger_on_change(&zk, move |paths, book_dir: &Path| -> Result<()> {
         info!("Files changed: {:?}", paths);
-        info!("Building book...");
 
-        let mut new_zk = load_zk(Some(book_dir.to_path_buf())).unwrap();
-        update_config(&mut new_zk, &livereload_url).unwrap();
+        let mut new_zk = load_zk(Some(book_dir.to_path_buf()))?;
+        update_config(&mut new_zk, &livereload_url)?;
         let result = match renderer.as_str() {
             "markdown" => new_zk.execute_build_process(&MarkdownRenderer),
             "mdzk" => new_zk.execute_build_process(&HtmlMdzk),
@@ -74,12 +73,13 @@ pub fn serve(dir: Option<PathBuf>, port: i32, bind: String, renderer: String) ->
         };
 
         if let Err(e) = result {
-            error!("Unable to load the book");
+            error!("Unable to load the mdzk");
             utils::log_backtrace(&e);
         } else {
             let _ = tx.send(Message::text("reload"));
         }
-    });
+        Ok(())
+    })?;
 
     let _ = thread_handle.join();
 
@@ -87,7 +87,6 @@ pub fn serve(dir: Option<PathBuf>, port: i32, bind: String, renderer: String) ->
 }
 
 fn update_config(book: &mut MDBook, livereload_url: &str) -> Result<()> {
-    // Override site-url for local serving of the 404 file
     book.config.set("output.html.site-url", "/")?;
     book.config
         .set("output.html.livereload-url", &livereload_url)?;
@@ -114,9 +113,7 @@ async fn serve_zk(
         .map(|ws: warp::ws::Ws, mut rx: broadcast::Receiver<Message>| {
             ws.on_upgrade(move |ws| async move {
                 let (mut user_ws_tx, _user_ws_rx) = ws.split();
-                trace!("websocket got connection");
                 if let Ok(m) = rx.recv().await {
-                    trace!("notify of reload");
                     let _ = user_ws_tx.send(m).await;
                 }
             })
